#ifndef CONFIGURE_H
#define CONFIGURE_H

#define CONFIG_DIR "/etc/steam"
#define LOG_DIR "/var/log/steam"

#define BRAND_NAME "steam"
#define STEAM_DIR "/usr/share/steam"

#define PREFIX_DIR "/usr"
#define INSTALL_DIR "/"

#define JAVA_HOME ""

#endif
